/*
** m_draft.c -- construct the name of a draft message
**
** This code is Copyright (c) 2002, by the authors of nmh.  See the
** COPYRIGHT file in the root directory of the nmh distribution for
** complete copyright information.
*/

#include <h/mh.h>
#include <h/utils.h>
#include <errno.h>


/*
**  `which' should either be "cur" to use the current draft
**  or "new" to start with a new draft.
*/
char *
m_draft(char *which)
{
	register char *cp;
	register struct msgs *mp;
	static char buffer[BUFSIZ];
	char *folder;

	cp = draftfolder;
	folder = path(*cp == '+' || *cp == '@' ? cp + 1 : cp,
			*cp != '@' ? TFOLDER : TSUBCWF);

	chdir(m_maildir(""));
	strncpy(buffer, m_maildir(folder), sizeof(buffer));

	create_folder(buffer, 0, done);

	if (chdir(buffer) == -1)
		adios(buffer, "unable to change directory to");

	if (!(mp = folder_read(folder)))
		adios(NULL, "unable to read folder %s", folder);

	/*
	** Make sure we have enough message status space for all
	** the message numbers from 1 to "new", since we might
	** select an empty slot.  If we add more space at the
	** end, go ahead and add 10 additional slots.
	*/
	if (mp->hghmsg >= mp->hghoff) {
		if (!(mp = folder_realloc(mp, 1, mp->hghmsg + 10)))
			adios(NULL, "unable to allocate folder storage");
	} else if (mp->lowoff > 1) {
		if (!(mp = folder_realloc(mp, 1, mp->hghoff)))
			adios(NULL, "unable to allocate folder storage");
	}

	mp->msgflags |= ALLOW_NEW;  /* allow the "new" sequence */

	/*
	** The draft message name to return is defined by `which'.
	** Usually it is "cur" (for the current draft) or "new"
	** (to start a new draft).
	*/
	if (!m_convert(mp, which))
		done(1);
	seq_setprev(mp);

	snprintf(buffer, sizeof(buffer), "%s/%s", mp->foldpath,
			m_name(mp->lowsel));
	seq_setcur(mp, mp->lowsel);
	seq_save(mp);
	folder_free(mp);

	return buffer;
}
